==> web-8.0.1.tgz: package/lib/calendar/index.js <==
import * as React from "react";
import { SlideBox } from "../animate/index";
import * as Immutable from "immutable";
import CalendarView from "./CalendarView";
import CalendarInp from "./CalendarInp";
import { timeStrValToTimeObjArr, calendarType, getInpTimeStrArr, getCurTime, getLastYear } from './objectFn';
import { event } from "../util/autoSlideUp";
class Calendar extends React.PureComponent {
    constructor(props) {
        super(props);
        this.eventId = new Date().getTime().toString();
        this.curTime = getCurTime();
        this.fixProps = this.createFixProps();
        this.changeBasicState = (key, callback, obj) => {
            if (obj && key === "selTimeArr") {
                const { selTimeArr, rotate } = this.state;
                const { time } = this.props;
                return this.compareTimeRang(selTimeArr, obj.viewIndex, obj.showTimeObj, rotate, time);
            }
            this.setState(pre => {
                const val = callback(pre);
                let obj = {};
                const { time } = this.props;
                if (key === "selTimeArr") {
                    const rotate = pre.rotate;
                    const calendarVal = getInpTimeStrArr(val, rotate, time).join(" 至 ");
                    obj = {
                        selTimeArr: val,
                        calendarVal,
                    };
                }
                else if (key === "rotate") {
                    const selTimeArr = pre.selTimeArr;
                    const calendarVal = getInpTimeStrArr(selTimeArr, val, time).join(" 至 ");
                    const showViewArr = this.getShowViewArr(val);
                    return {
                        calendarVal: calendarVal,
                        showViewArr: showViewArr,
                        rotate: val,
                    };
                }
                else {
                    obj = {
                        [key]: val,
                    };
                }
                return obj;
            }, () => {
                if (["rotate", "selTimeArr"].includes(key)) {
                    const { field, clickBack } = this.props;
                    const { rotate, calendarVal, selTimeArr } = this.state;
                    clickBack(calendarVal, field, rotate, selTimeArr);
                }
            });
        };
        this.documentClickFn = () => {
            this.setState({
                expand: false,
            });
        };
        const { time, rotate, clickBack, field, ableClear, renderCallBack, } = this.props;
        const selTimeArr = Immutable.fromJS(timeStrValToTimeObjArr(ableClear && !this.props.defaultTime, this.props, this.curTime));
        const timeVal = getInpTimeStrArr(selTimeArr, rotate, time);
        const showTimeArr = selTimeArr.getIn([0, "year"])
            ? selTimeArr
            : Immutable.fromJS(timeStrValToTimeObjArr(false, this.props, this.curTime));
        this.state = {
            expand: false,
            selTimeArr,
            showTimeArr,
            calendarVal: timeVal.join(" 至 "),
            rotate: rotate,
            pannelLastYear: showTimeArr.map((val) => {
                return getLastYear(val.get("year"));
            }),
            showViewArr: this.getShowViewArr(rotate),
            preInitTime: props.initTime,
            preRotate: props.rotate
        };
        if (renderCallBack) {
            clickBack(this.state.calendarVal, field, rotate, selTimeArr);
        }
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.initTime !== preState.preInitTime ||
            nextProps.rotate !== preState.preRotate) {
            const { time, rotate, clickBack, field, ableClear, renderCallBack, } = nextProps;
            const curTime = getCurTime();
            const objProps = nextProps.initTime ? Object.assign({}, nextProps, { defaultTime: nextProps.initTime.time }) : nextProps;
            const selTimeArr = Immutable.fromJS(timeStrValToTimeObjArr(ableClear, objProps, curTime));
            const timeVal = getInpTimeStrArr(selTimeArr, rotate, time);
            if (renderCallBack) {
                clickBack(selTimeArr, field, rotate, selTimeArr);
            }
            let animationArr = new Array(5).fill("fadeOut");
            animationArr[nextProps.rotate] = "fadeIn";
            const showTimeArr = selTimeArr.getIn([0, "year"])
                ? selTimeArr
                : Immutable.fromJS(timeStrValToTimeObjArr(false, objProps, curTime));
            return {
                expand: false,
                selTimeArr,
                showTimeArr,
                pannelLastYear: showTimeArr.map((val) => {
                    return val.get("year");
                }),
                calendarVal: timeVal.join(" 至 "),
                preInitTime: nextProps.initTime,
                rotate: nextProps.rotate,
                showViewArr: animationArr,
                preRotate: nextProps.rotate,
            };
        }
        else {
            return null;
        }
    }
    getShowViewArr(rotate) {
        let animationArr = new Array(5).fill("fadeOut");
        animationArr[rotate] = "fadeIn";
        return animationArr;
    }
    compareTimeRang(selTimeArr, viewIndex, showTimeObj, rotate, time) {
        const selTimeArrDate = selTimeArr.toJS();
        if (selTimeArrDate.length === 1 || !selTimeArr.getIn([0, "year"])) {
            return false;
        }
        selTimeArrDate[viewIndex] = showTimeObj;
        let startgtEnd = false;
        const startNode = selTimeArrDate[0];
        const endNode = selTimeArrDate[1];
        switch (rotate) {
            case calendarType.day:
                {
                    const mon1 = `${startNode.month}`.padStart(2, '0');
                    const day1 = `${startNode.day}`.padStart(2, '0');
                    const mon2 = `${endNode.month}`.padStart(2, '0');
                    const day2 = `${endNode.day}`.padStart(2, '0');
                    const startTime = `${startNode.year}${mon1}${day1}`;
                    const endTime = `${endNode.year}${mon2}${day2}`;
                    if (time) {
                        const hour1 = `${startNode.month}`.padStart(2, '0');
                        const minute1 = `${startNode.day}`.padStart(2, '0');
                        const hour2 = `${endNode.month}`.padStart(2, '0');
                        const minute2 = `${endNode.day}`.padStart(2, '0');
                        startgtEnd = startTime + `${hour1}${minute1}` > endTime + `${hour2}${minute2}`;
                    }
                    else {
                        startgtEnd = startTime > endTime;
                    }
                }
                break;
            case calendarType.month:
                {
                    const mon1 = `${startNode.month}`.padStart(2, '0');
                    const mon2 = `${endNode.month}`.padStart(2, '0');
                    startgtEnd = `${startNode.year}${mon1}` > `${endNode.year}${mon2}`;
                }
                break;
            case calendarType.searson:
                {
                    const season1 = startNode.searson;
                    const season2 = endNode.searson;
                    startgtEnd = `${startNode.year}${season1}` > `${endNode.year}${season2}`;
                }
                break;
            case calendarType.year:
                {
                    startgtEnd = `${startNode.year}` > `${endNode.year}`;
                }
                break;
            default:
                break;
        }
        return startgtEnd;
    }
    createFixProps() {
        const { style, time, noChangeRotate } = this.props;
        const obj = {
            style: style,
            time: time,
            noChangeRotate: noChangeRotate
        };
        return obj;
    }
    componentDidMount() {
        event.on(this.eventId, this.documentClickFn);
    }
    componentWillUnmount() {
        event.remove(this.eventId);
    }
    timeStrToNumber(strArr) {
        return strArr.map(val => {
            return val.replace(/-/g, "").replace(/:/g, "").replace(/\s/g, "");
        });
    }
    getSelTimeVal() {
        const { selTimeArr, calendarVal } = this.state;
        const { time, clickBack, field, rotate } = this.props;
        const strArr = getInpTimeStrArr(selTimeArr, rotate, time);
        const str = strArr.join(" 至 ");
        this.setState({
            calendarVal: str,
        }, () => {
            clickBack(calendarVal, field, rotate, selTimeArr);
        });
        return str;
    }
    render() {
        const { noInp, width, placeholder, ableClear, style, } = this.props;
        const { expand, selTimeArr, calendarVal, rotate, showViewArr, showTimeArr, pannelLastYear } = this.state;
        const inpCom = noInp ? undefined : (React.createElement(CalendarInp, { inpVal: calendarVal, placeholder: placeholder, eventId: this.eventId, ableClear: ableClear, curTime: this.curTime, changeBasicState: this.changeBasicState, style: style }));
        const secondViews = selTimeArr.size === 2 ? (React.createElement(CalendarView, { fixProps: this.fixProps, selTimeObj: selTimeArr.get(1), showTimeObj: showTimeArr.get(1), curTime: this.curTime, viewIndex: 1, lastYear: pannelLastYear.get(1), showViewArr: showViewArr, rotate: rotate, changeBasicState: this.changeBasicState })) : (undefined);
        const activeName = expand ? "autoSlideUp" : "";
        const boxW = style * 240;
        return (React.createElement("div", { className: "g-calendar " + activeName, "data-event": this.eventId, style: { width: ~~width, } },
            inpCom,
            React.createElement("div", { className: "g-calendar-box", style: { width: `${boxW}px`, } },
                React.createElement(SlideBox, { slide: expand },
                    React.createElement("div", { style: { display: "flex", } },
                        React.createElement(CalendarView, { fixProps: this.fixProps, selTimeObj: selTimeArr.get(0), showViewArr: showViewArr, curTime: this.curTime, lastYear: pannelLastYear.get(0), showTimeObj: showTimeArr.get(0), rotate: rotate, viewIndex: 0, changeBasicState: this.changeBasicState }),
                        secondViews)))));
    }
}
Calendar.defaultProps = {
    rotate: calendarType.day,
    style: 1,
    defaultTime: "",
    width: 280,
    placeholder: "",
};
export default Calendar;

==> web-8.1.0.tgz: package/lib/calendar/index.js <==
import * as React from "react";
import { SlideBox } from "../animate/index";
import * as Immutable from "immutable";
import CalendarView from "./CalendarView";
import CalendarInp from "./CalendarInp";
import { timeStrValToTimeObjArr, calendarType, getInpTimeStrArr, getCurTime, getLastYear, timeStrToNumber, } from "./objectFn";
import { event } from "../util/autoSlideUp";
class Calendar extends React.PureComponent {
    constructor(props) {
        super(props);
        this.eventId = new Date().getTime().toString();
        this.curTime = getCurTime();
        this.fixProps = this.createFixProps();
        this.changeBasicState = (key, callback, obj) => {
            if (obj && key === "selTimeArr") {
                const { selTimeArr, rotate } = this.state;
                const { time } = this.props;
                return this.compareTimeRang(selTimeArr, obj.viewIndex, obj.showTimeObj, rotate, time);
            }
            this.setState(pre => {
                const val = callback(pre);
                let obj = {};
                const { time } = this.props;
                if (key === "selTimeArr") {
                    const rotate = pre.rotate;
                    const calendarVal = getInpTimeStrArr(val, rotate, time).join(" 至 ");
                    obj = {
                        selTimeArr: val,
                        calendarVal,
                    };
                }
                else if (key === "rotate") {
                    const selTimeArr = pre.selTimeArr;
                    const calendarVal = getInpTimeStrArr(selTimeArr, val, time).join(" 至 ");
                    const showViewArr = this.getShowViewArr(val);
                    return {
                        calendarVal: calendarVal,
                        showViewArr: showViewArr,
                        rotate: val,
                    };
                }
                else {
                    obj = {
                        [key]: val,
                    };
                }
                return obj;
            }, () => {
                if (["rotate", "selTimeArr"].includes(key)) {
                    const { field, clickBack } = this.props;
                    const { rotate, calendarVal, selTimeArr } = this.state;
                    const val = timeStrToNumber(calendarVal.split(" 至 ")).join(",");
                    clickBack(val, field, rotate, selTimeArr);
                }
            });
        };
        this.documentClickFn = () => {
            this.setState({
                expand: false,
            });
        };
        const { time, rotate, clickBack, field, ableClear, renderCallBack, } = this.props;
        const selTimeArr = Immutable.fromJS(timeStrValToTimeObjArr(ableClear && !this.props.defaultTime, this.props, this.curTime));
        const timeVal = getInpTimeStrArr(selTimeArr, rotate, time);
        const showTimeArr = selTimeArr.getIn([0, "year"])
            ? selTimeArr
            : Immutable.fromJS(timeStrValToTimeObjArr(false, this.props, this.curTime));
        this.state = {
            expand: false,
            selTimeArr,
            showTimeArr,
            calendarVal: timeVal.join(" 至 "),
            rotate: rotate,
            pannelLastYear: showTimeArr.map((val) => {
                return getLastYear(val.get("year"));
            }),
            showViewArr: this.getShowViewArr(rotate),
            preInitTime: props.initTime,
            preRotate: props.rotate
        };
        if (renderCallBack) {
            const val = timeStrToNumber(timeVal).join(",");
            clickBack(val, field, rotate, selTimeArr);
        }
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.initTime !== preState.preInitTime ||
            nextProps.rotate !== preState.preRotate) {
            const { time, rotate, clickBack, field, ableClear, renderCallBack, } = nextProps;
            const curTime = getCurTime();
            const objProps = nextProps.initTime ? Object.assign({}, nextProps, { defaultTime: nextProps.initTime.time }) : nextProps;
            const selTimeArr = Immutable.fromJS(timeStrValToTimeObjArr(ableClear, objProps, curTime));
            const timeVal = getInpTimeStrArr(selTimeArr, rotate, time);
            if (renderCallBack) {
                clickBack(timeStrToNumber(timeVal).join(","), field, rotate, selTimeArr);
            }
            let animationArr = new Array(5).fill("fadeOut");
            animationArr[nextProps.rotate] = "fadeIn";
            const showTimeArr = selTimeArr.getIn([0, "year"])
                ? selTimeArr
                : Immutable.fromJS(timeStrValToTimeObjArr(false, objProps, curTime));
            return {
                expand: false,
                selTimeArr,
                showTimeArr,
                pannelLastYear: showTimeArr.map((val) => {
                    return val.get("year");
                }),
                calendarVal: timeVal.join(" 至 "),
                preInitTime: nextProps.initTime,
                rotate: nextProps.rotate,
                showViewArr: animationArr,
                preRotate: nextProps.rotate,
            };
        }
        else {
            return null;
        }
    }
    getShowViewArr(rotate) {
        let animationArr = new Array(5).fill("fadeOut");
        animationArr[rotate] = "fadeIn";
        return animationArr;
    }
    compareTimeRang(selTimeArr, viewIndex, showTimeObj, rotate, time) {
        const selTimeArrDate = selTimeArr.toJS();
        if (selTimeArrDate.length === 1 || !selTimeArr.getIn([0, "year"])) {
            return false;
        }
        selTimeArrDate[viewIndex] = showTimeObj;
        let startgtEnd = false;
        const startNode = selTimeArrDate[0];
        const endNode = selTimeArrDate[1];
        switch (rotate) {
            case calendarType.day:
                {
                    const mon1 = `${startNode.month}`.padStart(2, '0');
                    const day1 = `${startNode.day}`.padStart(2, '0');
                    const mon2 = `${endNode.month}`.padStart(2, '0');
                    const day2 = `${endNode.day}`.padStart(2, '0');
                    const startTime = `${startNode.year}${mon1}${day1}`;
                    const endTime = `${endNode.year}${mon2}${day2}`;
                    if (time) {
                        const hour1 = `${startNode.month}`.padStart(2, '0');
                        const minute1 = `${startNode.day}`.padStart(2, '0');
                        const hour2 = `${endNode.month}`.padStart(2, '0');
                        const minute2 = `${endNode.day}`.padStart(2, '0');
                        startgtEnd = startTime + `${hour1}${minute1}` > endTime + `${hour2}${minute2}`;
                    }
                    else {
                        startgtEnd = startTime > endTime;
                    }
                }
                break;
            case calendarType.month:
                {
                    const mon1 = `${startNode.month}`.padStart(2, '0');
                    const mon2 = `${endNode.month}`.padStart(2, '0');
                    startgtEnd = `${startNode.year}${mon1}` > `${endNode.year}${mon2}`;
                }
                break;
            case calendarType.searson:
                {
                    const season1 = startNode.searson;
                    const season2 = endNode.searson;
                    startgtEnd = `${startNode.year}${season1}` > `${endNode.year}${season2}`;
                }
                break;
            case calendarType.year:
                {
                    startgtEnd = `${startNode.year}` > `${endNode.year}`;
                }
                break;
            default:
                break;
        }
        return startgtEnd;
    }
    createFixProps() {
        const { style, time, noChangeRotate } = this.props;
        const obj = {
            style: style,
            time: time,
            noChangeRotate: noChangeRotate
        };
        return obj;
    }
    componentDidMount() {
        event.on(this.eventId, this.documentClickFn);
    }
    componentWillUnmount() {
        event.remove(this.eventId);
    }
    getSelTimeVal() {
        const { selTimeArr } = this.state;
        const { time, clickBack, field, rotate } = this.props;
        const strArr = getInpTimeStrArr(selTimeArr, rotate, time);
        const str = strArr.join(" 至 ");
        this.setState({
            calendarVal: str,
        }, () => {
            const val = timeStrToNumber(strArr);
            clickBack(val.join(","), field, rotate, selTimeArr);
        });
        return str;
    }
    render() {
        const { noInp, width, placeholder, ableClear, style, } = this.props;
        const { expand, selTimeArr, calendarVal, rotate, showViewArr, showTimeArr, pannelLastYear } = this.state;
        const inpCom = noInp ? undefined : (React.createElement(CalendarInp, { inpVal: calendarVal, placeholder: placeholder, eventId: this.eventId, ableClear: ableClear, curTime: this.curTime, changeBasicState: this.changeBasicState, style: style }));
        const secondViews = selTimeArr.size === 2 ? (React.createElement(CalendarView, { fixProps: this.fixProps, selTimeObj: selTimeArr.get(1), showTimeObj: showTimeArr.get(1), curTime: this.curTime, viewIndex: 1, lastYear: pannelLastYear.get(1), showViewArr: showViewArr, rotate: rotate, changeBasicState: this.changeBasicState })) : (undefined);
        const activeName = expand ? "autoSlideUp" : "";
        const showViewIndex = showViewArr.indexOf("fadeIn");
        console.log(showViewIndex);
        const boxW = style * ([235, 235, 228, 235, 292][showViewIndex]);
        return (React.createElement("div", { className: "g-calendar " + activeName, "data-event": this.eventId, style: { width: ~~width, } },
            inpCom,
            React.createElement("div", { className: "g-calendar-box", style: { width: `${boxW}px`, } },
                React.createElement(SlideBox, { slide: expand },
                    React.createElement("div", { style: { display: "flex", } },
                        React.createElement(CalendarView, { fixProps: this.fixProps, selTimeObj: selTimeArr.get(0), showViewArr: showViewArr, curTime: this.curTime, lastYear: pannelLastYear.get(0), showTimeObj: showTimeArr.get(0), rotate: rotate, viewIndex: 0, changeBasicState: this.changeBasicState }),
                        secondViews)))));
    }
}
Calendar.defaultProps = {
    rotate: calendarType.day,
    style: 1,
    defaultTime: "",
    width: 280,
    placeholder: "",
};
export default Calendar;
